--[[
	Copyright (C) 2015  Fuhrbolg

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>

	Author's note: Under no circumstances should this Addon be used under any situation.
	It is dangerous and will cause significant harm to your computer. You have been warned.
--]]

local ADDON_NAME, T = ...

--[[
 -	Library verification follows.
--]]
if not LibStub then
    error(ADDON_NAME, " requires LibStub")
    return
end

if not LibStub("AceAddon-3.0") then
    error(ADDON_NAME, " requires AceAddon-3.0")
    return;
end

if not LibStub("AceLocale-3.0") then
    error(ADDON_NAME, " requires AceLocale-3.0")
    return
end

if not LibStub("CallbackHandler-1.0") then
    error(ADDON_NAME, " requires CallbackHandler-1.0")
    return
end

if not LibStub("LibNameplateRegistry-1.0") then
    error(ADDON_NAME, " requires LibNameplateRegistry-1.0")
    return
end

if not LibStub("LibButtonGlow-1.0") then
	error(ADDON_NAME, " requires LibButtonGlow-1.0")
	return
end

-- Localization
local L = LibStub("AceLocale-3.0"):GetLocale("MongoMon")

--[[
 -	Section is dedicated to the Interface Options panel.
--]]

-- Our options object of supreme power
MongoMonOptions = { 
	scoreEnabled = true,			-- Toggle player's scoreboard in battleground
	portraitEnabled = true,			-- Toggle portraits for unit frames
	soundEnabled = true,			-- Toggle sounds on/off
	nameplatesEnabled = true,		-- Toggle special mongo nameplates
	flashEnabled = true,			-- Toggle scoreboard flash when it updates
	topRanks = 5					-- Display this many top ranks in bg (#1, #2, and #3)
}

-- Main options panel frame
local FRAME_WIDTH = 500
local frame = CreateFrame( "Frame", "MongoMonOptionsFrame", UIParent )
frame:RegisterEvent("ADDON_LOADED")
frame.name = L["Title"]
frame:SetPoint("TOPLEFT", UIParent, "TOPLEFT")
InterfaceOptions_AddCategory(frame)

-- Title Pane
frame.title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalHugeOutline2")
-- frame.title:SetPoint("TOPLEFT", 20, -20)
frame.title:SetPoint("TOPLEFT", frame, 20, -20)
frame.title:SetText(L["Title"])
frame.title:SetWidth(FRAME_WIDTH)
frame.title:SetJustifyH("LEFT")

-- Subtitle Pane
frame.subTitle = frame:CreateFontString(nil, "ARTWORK", "NumberFont_Normal_Med")
frame.subTitle:SetPoint("TOPLEFT", frame.title, "BOTTOMLEFT", 0, -10)
frame.subTitle:SetText(L["Subtitle"])
frame.subTitle:SetWidth(FRAME_WIDTH)
frame.subTitle:SetJustifyH("LEFT")

-- Description Pane
frame.description = frame:CreateFontString(nil, "ARTWORK", "NumberFont_Shadow_Small")
frame.description:SetPoint("TOPLEFT", frame.subTitle, "BOTTOMLEFT", 0, -10)
frame.description:SetText(L["Description"])
frame.description:SetWidth(FRAME_WIDTH)
frame.description:SetJustifyH("LEFT")

-- Portraits Enabled Checkbox
frame.portraitEnabledCheckBox = CreateFrame("CheckButton", "MongoMonOptions_PortraitEnabledCheckbox", frame, "InterfaceOptionsCheckButtonTemplate")
frame.portraitEnabledCheckBox.text = _G["MongoMonOptions_PortraitEnabledCheckboxText"]
frame.portraitEnabledCheckBox.text:SetText(L["EnablePortrait"])
frame.portraitEnabledCheckBox:SetPoint("TOPLEFT", frame.description, "BOTTOMLEFT", 0, -20)
frame.portraitEnabledCheckBox:SetChecked(MongoMonOptions.portraitEnabled)
frame.portraitEnabledCheckBox:SetScript("OnClick", 
	function()
		MongoMonOptions.portraitEnabled = frame.portraitEnabledCheckBox:GetChecked()
	end
)

-- Portraits Description
frame.portraitDescription = frame:CreateFontString(nil, "ARTWORK", "NumberFont_Shadow_Small")
frame.portraitDescription:SetPoint("TOPLEFT", frame.portraitEnabledCheckBox, "BOTTOMLEFT", 0, -5)
frame.portraitDescription:SetText(L["PortraitDescription"])
frame.portraitDescription:SetWidth(FRAME_WIDTH)
frame.portraitDescription:SetJustifyH("LEFT")

-- Sound Checkbox
frame.soundEnabledCheckBox = CreateFrame("CheckButton", "MongoMonOptions_SoundEnabledCheckbox", frame, "InterfaceOptionsCheckButtonTemplate")
frame.soundEnabledCheckBox.text = _G["MongoMonOptions_SoundEnabledCheckboxText"]
frame.soundEnabledCheckBox.text:SetText(L["EnableSound"])
frame.soundEnabledCheckBox:SetPoint("TOPLEFT", frame.portraitDescription, "BOTTOMLEFT", 0, -20)
frame.soundEnabledCheckBox:SetChecked(MongoMonOptions.soundEnabled)
frame.soundEnabledCheckBox:SetScript("OnClick", 
	function()
		MongoMonOptions.soundEnabled = frame.soundEnabledCheckBox:GetChecked()
	end
)

-- Sound Description
frame.soundDescription = frame:CreateFontString(nil, "ARTWORK", "NumberFont_Shadow_Small")
frame.soundDescription:SetPoint("TOPLEFT", frame.soundEnabledCheckBox, "BOTTOMLEFT", 0, -5)
frame.soundDescription:SetText(L["SoundDescription"])
frame.soundDescription:SetWidth(FRAME_WIDTH)
frame.soundDescription:SetJustifyH("LEFT")

-- Nameplates Checkbox
frame.nameplatesEnabledCheckBox = CreateFrame("CheckButton", "MongoMonOptions_NameplatesEnabledCheckbox", frame, "InterfaceOptionsCheckButtonTemplate")
frame.nameplatesEnabledCheckBox.text = _G["MongoMonOptions_NameplatesEnabledCheckboxText"]
frame.nameplatesEnabledCheckBox.text:SetText(L["EnableNameplates"])
frame.nameplatesEnabledCheckBox:SetPoint("TOPLEFT", frame.soundDescription, "BOTTOMLEFT", 0, -20)
frame.nameplatesEnabledCheckBox:SetChecked(MongoMonOptions.nameplatesEnabled)
frame.nameplatesEnabledCheckBox:SetScript("OnClick", 
	function()
		MongoMonOptions.nameplatesEnabled = frame.nameplatesEnabledCheckBox:GetChecked()
	end
)

-- Nameplates Description
frame.nameplatesDescription = frame:CreateFontString(nil, "ARTWORK", "NumberFont_Shadow_Small")
frame.nameplatesDescription:SetPoint("TOPLEFT", frame.nameplatesEnabledCheckBox, "BOTTOMLEFT", 0, -5)
frame.nameplatesDescription:SetText(L["NameplatesDescription"])
frame.nameplatesDescription:SetWidth(FRAME_WIDTH)
frame.nameplatesDescription:SetJustifyH("LEFT")

-- Scoreboard Checkbox
frame.scoreEnabledCheckBox = CreateFrame("CheckButton", "MongoMonOptions_ScoreEnabledCheckbox", frame, "InterfaceOptionsCheckButtonTemplate")
frame.scoreEnabledCheckBox.text = _G["MongoMonOptions_ScoreEnabledCheckboxText"]
frame.scoreEnabledCheckBox.text:SetText(L["EnableScore"])
frame.scoreEnabledCheckBox:SetPoint("TOPLEFT", frame.nameplatesDescription, "BOTTOMLEFT", 0, -20)
frame.scoreEnabledCheckBox:SetChecked(MongoMonOptions.scoreEnabled)
frame.scoreEnabledCheckBox:SetScript("OnClick", 
	function()
		MongoMonOptions.scoreEnabled = frame.scoreEnabledCheckBox:GetChecked()
	end
)

-- Score Description
frame.scoreDescription = frame:CreateFontString(nil, "ARTWORK", "NumberFont_Shadow_Small")
frame.scoreDescription:SetPoint("TOPLEFT", frame.scoreEnabledCheckBox, "BOTTOMLEFT", 0, -5)
frame.scoreDescription:SetText(L["ScoreDescription"])
frame.scoreDescription:SetWidth(FRAME_WIDTH)
frame.scoreDescription:SetJustifyH("LEFT")

-- Flash Checkbox
frame.flashEnabledCheckBox = CreateFrame("CheckButton", "MongoMonOptions_FlashEnabledCheckbox", frame, "InterfaceOptionsCheckButtonTemplate")
frame.flashEnabledCheckBox.text = _G["MongoMonOptions_FlashEnabledCheckboxText"]
frame.flashEnabledCheckBox.text:SetText(L["EnableFlash"])
frame.flashEnabledCheckBox:SetPoint("TOPLEFT", frame.scoreDescription, "BOTTOMLEFT", 0, -20)
frame.flashEnabledCheckBox:SetChecked(MongoMonOptions.flashEnabled)
frame.flashEnabledCheckBox:SetScript("OnClick", 
	function()
		MongoMonOptions.flashEnabled = frame.flashEnabledCheckBox:GetChecked()
	end
)

-- Flash Description
frame.flashDescription = frame:CreateFontString(nil, "ARTWORK", "NumberFont_Shadow_Small")
frame.flashDescription:SetPoint("TOPLEFT", frame.flashEnabledCheckBox, "BOTTOMLEFT", 0, -5)
frame.flashDescription:SetText(L["FlashDescription"])
frame.flashDescription:SetWidth(FRAME_WIDTH)
frame.flashDescription:SetJustifyH("LEFT")

--[[
 -	Load saved variables into our table
--]]
frame:SetScript("OnEvent", function(self, event, arg1)
	if event == "ADDON_LOADED" and arg1 == "MongoMon" then
		-- Do we need this?
	end
end)

--[[
 -	MongoMon slash commands
 -
 -	/mm Will open the Interface options menu and print out some garbage
--]]
SLASH_MONGOMON1 = '/mm'
function SlashCmdList.MONGOMON(msg, editbox)
	InterfaceOptionsFrame_OpenToCategory(ADDON_NAME)
	InterfaceOptionsFrame_OpenToCategory(ADDON_NAME)
	print(L["Console"])
end